pub struct BidPoolResponse {
pub sum_snapshot: Decimal256,
pub product_snapshot: Decimal256,
pub total_bid_amount: Uint256,
pub premium_rate: Decimal256,
pub current_epoch: Uint128,
pub current_scale: Uint128,
}Fields
sum_snapshot: Decimal256product_snapshot: Decimal256total_bid_amount: Uint256current_epoch: Uint128current_scale: Uint128Trait Implementations
Sourceimpl Clone for BidPoolResponse
impl Clone for BidPoolResponse
Sourcefn clone(&self) -> BidPoolResponse
fn clone(&self) -> BidPoolResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BidPoolResponse
impl Debug for BidPoolResponse
Sourceimpl<'de> Deserialize<'de> for BidPoolResponse
impl<'de> Deserialize<'de> for BidPoolResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BidPoolResponse
impl JsonSchema for BidPoolResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BidPoolResponse
impl PartialEq for BidPoolResponse
Sourcefn eq(&self, other: &BidPoolResponse) -> bool
fn eq(&self, other: &BidPoolResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for BidPoolResponse
impl Serialize for BidPoolResponse
impl Eq for BidPoolResponse
impl StructuralPartialEq for BidPoolResponse