pub struct InstantiateMsg {
pub owner: String,
pub oracle_contract: String,
pub stable_contract: String,
pub safe_ratio: Decimal256,
pub bid_fee: Decimal256,
pub liquidator_fee: Decimal256,
pub liquidation_threshold: Uint256,
pub price_timeframe: u64,
pub waiting_period: u64,
pub overseer: String,
}Fields
owner: Stringoracle_contract: Stringstable_contract: Stringsafe_ratio: Decimal256borrow_amount / borrow_limit must always be bigger than
safe_ratio.
bid_fee: Decimal256Fee applied to executed bids Sent to Overseer interest buffer
liquidator_fee: Decimal256Fee applied to executed bids Sent to the address executing the liquidation
liquidation_threshold: Uint256Liquidation threshold amount in stable denom. When the current collaterals value is smaller than the threshold, all collaterals will be liquidated
price_timeframe: u64Valid oracle price timeframe
waiting_period: u64Time period that needs to pass for a bid to be activated (seconds)
overseer: StringTrait Implementations
Sourceimpl Clone for InstantiateMsg
impl Clone for InstantiateMsg
Sourcefn clone(&self) -> InstantiateMsg
fn clone(&self) -> InstantiateMsg
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InstantiateMsg
impl Debug for InstantiateMsg
Sourceimpl<'de> Deserialize<'de> for InstantiateMsg
impl<'de> Deserialize<'de> for InstantiateMsg
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for InstantiateMsg
impl JsonSchema for InstantiateMsg
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for InstantiateMsg
impl PartialEq for InstantiateMsg
Sourcefn eq(&self, other: &InstantiateMsg) -> bool
fn eq(&self, other: &InstantiateMsg) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for InstantiateMsg
impl Serialize for InstantiateMsg
impl Eq for InstantiateMsg
impl StructuralPartialEq for InstantiateMsg