pub struct StateResponse {
pub total_bond: Uint128,
pub total_supply: Uint128,
pub exchange_rate: Uint128,
}Fields
total_bond: Uint128total_supply: Uint128exchange_rate: Uint128Trait Implementations
Sourceimpl Clone for StateResponse
impl Clone for StateResponse
Sourcefn clone(&self) -> StateResponse
fn clone(&self) -> StateResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StateResponse
impl Debug for StateResponse
Sourceimpl<'de> Deserialize<'de> for StateResponse
impl<'de> Deserialize<'de> for StateResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StateResponse
impl JsonSchema for StateResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for StateResponse
impl PartialEq for StateResponse
Sourcefn eq(&self, other: &StateResponse) -> bool
fn eq(&self, other: &StateResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for StateResponse
impl Serialize for StateResponse
impl Eq for StateResponse
impl StructuralPartialEq for StateResponse